@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package MetaCPAN::Client;
 # ABSTRACT: A comprehensive, DWIM-featured client to the MetaCPAN API
-$MetaCPAN::Client::VERSION = '2.036000';
+$MetaCPAN::Client::VERSION = '2.038000';
 use Moo;
 use Carp;
 use Ref::Util qw< is_arrayref is_hashref is_ref >;
@@ -23,6 +23,7 @@ use MetaCPAN::Client::Package;
 use MetaCPAN::Client::Permission;
 use MetaCPAN::Client::ResultSet;
 use MetaCPAN::Client::Cover;
+use MetaCPAN::Client::CVE;
 
 has request => (
     is      => 'ro',
@@ -30,7 +31,7 @@ has request => (
 );
 
 my @supported_searches = qw<
-    author distribution favorite module rating release mirror file permission package cover
+    author distribution favorite module rating release mirror file permission package cover cve
 >;
 
 sub BUILDARGS {
@@ -102,6 +103,14 @@ sub cover {
     return $self->_get_or_search( 'cover', $arg, $params );
 }
 
+sub cve {
+    my $self   = shift;
+    my $arg    = shift;
+    my $params = shift;
+
+    return $self->_get_or_search( 'cve', $arg, $params );
+}
+
 sub pod {
     my $self   = shift;
     my $name   = shift;
@@ -170,7 +179,11 @@ sub recent {
     $size eq 'today'
         and return $self->_recent(
             size   => 1000,
-            filter => _filter_today()
+            query => {
+                bool => {
+                    filter => _filter_today()
+                }
+            }
         );
 
     $size =~ /^[0-9]+$/
@@ -293,8 +306,13 @@ sub _get {
         or croak sprintf( 'Failed to fetch %s (%s)', ucfirst($type), $arg );
 
     $type = 'DownloadURL' if $type eq 'download_url';
-
     my $class = 'MetaCPAN::Client::' . ucfirst($type);
+
+    if ( $type eq 'cve' and is_hashref($response) and is_arrayref($response->{cve} ) ) {
+        $class =~ s/Cve/CVE/;
+        $response = $response->{cve}[0];
+    }
+
     return $class->new_from_request($response, $self);
 }
 
@@ -371,12 +389,13 @@ sub _reverse_deps {
             "/reverse_dependencies/dist/$dist",
             {
                 size   => 5000,
-                query  => { match_all => {} },
-                filter => {
-                    and => [
-                        { term => { 'status'     => 'latest' } },
-                        { term => { 'authorized' => 1        } },
-                    ]
+                query  => {
+                    bool => {
+                        must => [
+                            { term => { 'status'     => 'latest' } },
+                            { term => { 'authorized' => 1        } },
+                        ]
+                    }
                 },
             }
         );
@@ -449,7 +468,7 @@ MetaCPAN::Client - A comprehensive, DWIM-featured client to the MetaCPAN API
 
 =head1 VERSION
 
-version 2.036000
+version 2.038000
 
 =head1 SYNOPSIS
 
@@ -527,6 +546,12 @@ L<MetaCPAN::Client::Author> objects on a complex (L<search spec based|/"SEARCH S
 
 Returns a L<MetaCPAN::Client::Cover> object.
 
+=head2 cve
+
+    my $cve = $mcpan->cve('CPANSA-DBD-SQLite-2019-5018');
+
+Returns a L<MetaCPAN::Client::CVE> object.
+
 =head2 distribution
 
     my $dist = $mcpan->distribution('MetaCPAN-Client');
